@@ -9,7 +9,6 @@ from simplegeo import Client as ParentClient
 class Client(ParentClient):
 
     def __init__(self, key, secret, api_version='1.0', **kwargs):
-        self.subclient = True
         ParentClient.__init__(self, key, secret, **kwargs)
 
         context_endpoints = [
@@ -22,22 +21,31 @@ class Client(ParentClient):
 
         self.endpoints.update(map(lambda x: (x[0], api_version+x[1]), context_endpoints))
 
-    def get_context(self, lat, lon, filter=None):
+    def _prepare_kwargs(self, **kwargs):
+        if 'context_args' in kwargs and kwargs['context_args']:
+            context_args = kwargs['context_args']
+            del kwargs['context_args']
+            kwargs.update(context_args)
+        # Filter out entries with empty values.
+        kwargs = dict((k, v) for k, v in kwargs.iteritems() if v)
+        return kwargs
+
+    def get_context(self, lat, lon, filter=None, context_args=None):
         _assert_valid_lat(lat)
         _assert_valid_lon(lon)
 
         if (filter and not isinstance(filter, basestring)):
             raise ValueError("Query must be a string.")
 
-        kwargs = { }
-        if filter:
-            kwargs['filter'] = filter
+        kwargs = self._prepare_kwargs(
+            filter=filter,
+            context_args=context_args)
 
         endpoint = self._endpoint('context', lat=lat, lon=lon)
         result = self._request(endpoint, 'GET', data=kwargs)[1]
         return json_decode(result)
 
-    def get_context_by_ip(self, ipaddr, filter=None):
+    def get_context_by_ip(self, ipaddr, filter=None, context_args=None):
         """ The server uses guesses the latitude and longitude from
         the ipaddr and then does the same thing as get_context(),
         using that guessed latitude and longitude."""
@@ -47,15 +55,15 @@ class Client(ParentClient):
         if (filter and not isinstance(filter, basestring)):
             raise ValueError("Query must be a string.")
 
-        kwargs = { }
-        if filter:
-            kwargs['filter'] = filter
+        kwargs = self._prepare_kwargs(
+            filter=filter,
+            context_args=context_args)
 
         endpoint = self._endpoint('context_by_ip', ip=ipaddr)
         result = self._request(endpoint, 'GET', data=kwargs)[1]
         return json_decode(result)
 
-    def get_context_by_my_ip(self, filter=None):
+    def get_context_by_my_ip(self, filter=None, context_args=None):
         """ The server gets the IP address from the HTTP connection
         (this may be the IP address of your device or of a firewall,
         NAT, or HTTP proxy device between you and the server), and
@@ -65,15 +73,15 @@ class Client(ParentClient):
         if (filter and not isinstance(filter, basestring)):
             raise ValueError("Query must be a string.")
 
-        kwargs = { }
-        if filter:
-            kwargs['filter'] = filter
+        kwargs = self._prepare_kwargs(
+            filter=filter,
+            context_args=context_args)
 
         endpoint = self._endpoint('context_by_my_ip')
         result = self._request(endpoint, 'GET', data=kwargs)[1]
         return json_decode(result)
 
-    def get_context_by_address(self, address, filter=None):
+    def get_context_by_address(self, address, filter=None, context_args=None):
         """
         The server figures out the latitude and longitude from the
         street address and then does the same thing as get_context(),
@@ -85,11 +93,10 @@ class Client(ParentClient):
         if (filter and not isinstance(filter, basestring)):
             raise ValueError("Query must be a string.")
 
-        kwargs = { }
-        if filter:
-            kwargs['filter'] = filter
-        if address:
-            kwargs['address'] = address
+        kwargs = self._prepare_kwargs(
+            address=address,
+            filter=filter,
+            context_args=context_args)
 
         endpoint = self._endpoint('context_by_address')
         result = self._request(endpoint, 'GET', data=kwargs)[1]
@@ -107,6 +114,9 @@ class Client(ParentClient):
         responses, so the order here is (minlat, minlon, maxlat, maxlon).
         """
 
+        kwargs = self._prepare_kwargs(
+            context_args=kwargs)
+
         endpoint = self._endpoint('context_from_bbox',
                                   sw_lat=sw_lat, sw_lon=sw_lon,
                                   ne_lat=ne_lat, ne_lon=ne_lon)
